@@ -61,7 +61,9 @@
             pointer->diff-hunk
 
             config-entry? pointer->config-entry
-            config-entry-name config-entry-value config-entry-include-depth config-entry-level
+            config-entry-name config-entry-value config-entry-include-depth
+            config-entry-level config-entry-backend-type
+            config-entry-origin-path
 
             status-entry? status-entry-status status-entry-head-to-index status-entry-index-to-workdir pointer->status-entry
 
@@ -494,18 +496,28 @@
 
 ;; config entry
 
-(define %config-entry (bs:struct `((name ,(bs:pointer uint8)) ; char *
-                                   (value ,(bs:pointer uint8)) ; char *
-                                   (include-depth ,unsigned-int)
-                                   (level ,int) ; git_config_level_t
-                                   (free ,(bs:pointer int))
-                                   (payload ,(bs:pointer int)))))
+(define %config-entry
+  (bs:struct `((name ,(bs:pointer uint8))         ;char *
+               (value ,(bs:pointer uint8))        ;char *
+               ,@(if %have-config-entry-backend-type?
+                     `((backend-type ,(bs:pointer uint8)) ;char *
+                       (origin-path ,(bs:pointer uint8))) ;char *
+                     '())
+               (include-depth ,unsigned-int)
+               (level ,int)                       ;git_config_level_t
+               (free ,(bs:pointer int))
+               ,@(if %have-config-entry-backend-type?
+                     '()
+                     `((payload ,(bs:pointer int))))))) ;removed in 1.8
 
 (define-record-type <config-entry>
-  (%make-config-entry name value depth level)
+  (%make-config-entry name value backend-type origin-path
+                      depth level)
   config-entry?
   (name   config-entry-name)
   (value  config-entry-value)
+  (backend-type config-entry-backend-type)        ;#f | symbol
+  (origin-path  config-entry-origin-path)         ;#f | string
   (depth  config-entry-include-depth)
   (level  config-entry-level))
 
@@ -519,6 +531,13 @@ pointed to by POINTER.  The data pointed to by POINTER is not freed."
   (%make-config-entry
    (pointer->string (make-pointer (bytestructure-ref bs 'name)))
    (pointer->string (make-pointer (bytestructure-ref bs 'value)))
+   (and %have-config-entry-backend-type?
+        (string->symbol
+         (pointer->string
+          (make-pointer (bytestructure-ref bs 'backend-type)))))
+   (and %have-config-entry-backend-type?
+        (pointer->string
+         (make-pointer (bytestructure-ref bs 'origin-path))))
    (bytestructure-ref bs 'include-depth)
    (bytestructure-ref bs 'level)))
 
