@@ -1,7 +1,7 @@
 ;;; Guile-Git --- GNU Guile bindings of libgit2
 ;;; Copyright © 2016 Amirouche Boubekki <amirouche@hypermove.net>
 ;;; Copyright © 2016, 2017 Erik Edrosa <erik.edrosa@gmail.com>
-;;; Copyright © 2017, 2018 Ludovic Courtès <ludo@gnu.org>
+;;; Copyright © 2017-2018, 2024 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of Guile-Git.
 ;;;
@@ -89,6 +89,12 @@
            (out (repository-directory repository)))
       (string-trim-right out #\/)))
 
+  (test-equal "repository-common-directory"
+    (canonicalize-path (string-append directory "/.git"))
+    (let* ((repository (repository-open directory))
+           (out (repository-common-directory repository)))
+      (string-trim-right out #\/)))
+
   (test-equal "repository-discover"
     (canonicalize-path (string-append directory "/.git"))
     (let ((path (repository-discover
